@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIResponseWriter.h 2297 2006-12-24 03:13:15Z svn $
+ * $Id: CGIResponseWriter.h 2508 2007-07-06 22:47:18Z svn $
  *****************************************************************************/
 
 #ifndef CGI_RESPONSE_WRITER_H
@@ -50,7 +50,7 @@ public:
     };
     void write(const char *str, apr_size_t length) const
     {
-        std::cout.write(str, static_cast<streamsize>(length));
+        std::cout.write(str, static_cast<std::streamsize>(length));
 #ifdef DEBUG_TemplateExecutor
         std::cout.flush();
 #endif
@@ -73,10 +73,19 @@ public:
     {
         std::cout.flush();
     };
+    static bool is_sendfile_enabled(CGIResponse::Handle *r){
+        return false;
+    };
     static int sendfile(CGIResponse::Handle *r,
                         apr_file_t *file, apr_uint64_t length)
     {
-        // TODO: 実装する
+        char buffer[SYS_PAGE_SIZE];
+
+        for (apr_size_t read_size = sizeof(buffer);
+             apr_file_read(file, buffer, &read_size) == APR_SUCCESS;) {
+            std::cout.write(buffer, static_cast<std::streamsize>(read_size));
+        }
+
         return OK;
     };
 };
