@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2007 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ConfigReader.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: ConfigReader.h 2501 2007-07-06 15:27:30Z svn $
  *****************************************************************************/
 
 #ifndef CONFIG_READER_H
@@ -30,11 +30,10 @@
 
 #include "Environment.h"
 
-#include <cstdlib>
+#include <string>
+#include <map>
 
-#include "apr_tables.h"
-
-#include "Uncopyable.h"
+#include "apr_pools.h"
 
 
 /**
@@ -43,21 +42,26 @@
 class ConfigReader: public Uncopyable
 {
 public:
-    static apr_table_t *read(apr_pool_t *pool, const char *conf_file_path);
+    typedef std::map<std::string, std::string> config_map; // multimap ではない！
+    typedef std::pair<std::string, std::string> config_pair;
+
+    static config_map *read(apr_pool_t *pool, const char *file_path);
 
 private:
     static const char COMMENT_CHAR;
     static const char QUOTE_CHAR;
     static const char ASSIGN_CHAR;
 
-    static bool read_line(apr_pool_t *pool, const char **input,
+    static void read_file(apr_pool_t *pool, const char *file_path,
+                          const char **data);
+    static void read_line(apr_pool_t *pool, const char **data,
                           const char **name, const char **value);
-    static void read_param(apr_pool_t *pool, const char **input,
+    static void read_param(apr_pool_t *pool, const char **data,
                            const char **name, const char **value);
-    static void read_word(apr_pool_t *pool, const char **input,
+    static void read_word(apr_pool_t *pool, const char **data,
                           const char **word);
-    static void skip_space(const char **input);
-    static void skip_line(const char **input);
+    static void skip_space(const char **data);
+    static void skip_line(const char **data);
 };
 
 #endif
