@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2484 2007-07-03 15:14:44Z svn $
+ * $Id: ReadLocker.h 2513 2007-07-09 13:05:22Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -32,10 +32,6 @@
 
 #include "ReadWriteLocker.h"
 
-#ifdef DEBUG
-#include <iostream>
-#endif
-using namespace std;
 
 /**
  * @brief 読み出しロックを表すクラス．
@@ -59,28 +55,26 @@ public:
         while (1) {
             try_count++;
 
-            curr_status = apr_atomic_read(lock_);
-            if (LIKELY((get_read_count(curr_status) != WRITE_LOCKED) &&
-                       ((get_wait_write(curr_status) != WAIT_WRITE) ||
-                        (get_prefer_write(curr_status) != PREFER_WRITE)))) {
-                new_status = make_status(get_age(curr_status),
-                                         get_read_count(curr_status) + 1,
-                                         get_prefer_write(curr_status),
-                                         get_wait_write(curr_status));
-                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
-                    status_ = new_status;
-                    log_try_count("ReadLock", try_count);
+            curr_status = apr_atomic_read(lock);
+            if (LIKELY(can_lock(curr_status))) {
+                new_status = (curr_status + READ_COUNT_UINIT) & VALID_MASK;
+                status_ = new_status; // 先に更新しておく
+                if (apr_atomic_cas(lock, new_status, curr_status) ==
+                    curr_status) {
+                    log_try_count("ReadLock",
+                                  try_count, curr_status, new_status);
                     return;
                 }
             } else if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
-                       is_timeout(curr_status)) {
+                       should_timeout(curr_status)) {
                 // タイムアウトしたら age を増やす
-                new_status = make_status(get_age(curr_status) + 1, 1,
-                                         get_prefer_write(curr_status),
-                                         get_wait_write(curr_status));
-                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
-                    status_ = new_status;
-                    log_try_count("ReadLock(TIME OUT)", try_count);
+                new_status = (((curr_status & (~READ_COUNT_MASK)) |
+                               READ_COUNT_UINIT) + AGE_UINIT) & VALID_MASK;
+                status_ = new_status; // 先に更新しておく
+                if (apr_atomic_cas(lock, new_status, curr_status) ==
+                    curr_status) {
+                    log_try_count("ReadLock(TIME OUT)",
+                                  try_count, curr_status, new_status);
                     return;
                 }
             }
@@ -92,27 +86,28 @@ public:
     {
         apr_size_t try_count;
         apr_uint32_t curr_status;
+        apr_uint32_t new_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
             curr_status = apr_atomic_read(lock_);
-            if (get_age(curr_status) != get_age(status_)) {
+            if (UNLIKELY(is_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
-                log_try_count("ReadUnLock(TIME OUT)", try_count);
+                log_try_count("ReadUnLock(TIME OUT)",
+                              try_count, curr_status, curr_status);
                 return;
             }
 
             // read_count は変更されている可能性があることに注意！
 
-            if (apr_atomic_cas(lock_,
-                               make_status(get_age(curr_status),
-                                           get_read_count(curr_status) - 1,
-                                           PREFER_WRITE,
-                                           get_wait_write(curr_status)),
-                               curr_status) == curr_status) {
-                log_try_count("ReadUnLock", try_count);
+            new_status = (((curr_status | RESERVED_MASK) - READ_COUNT_UINIT) |
+                          PREFER_WRITE) & VALID_MASK;
+            if (apr_atomic_cas(lock_, new_status, curr_status) ==
+                curr_status) {
+                log_try_count("ReadUnLock",
+                              try_count, curr_status, new_status);
                 return;
             }
         }
@@ -120,6 +115,13 @@ public:
     static bool is_locked(apr_atomic_t *lock) {
         return get_read_count(apr_atomic_read(lock)) != NOT_LOCKED;
     };
+private:
+    bool can_lock(apr_uint32_t status)
+    {
+        return ((get_read_count(status) != WRITE_LOCKED) &&
+                ((status & (PREFER_WRITE_MASK|WAIT_WRITE_MASK)) !=
+                 (WAIT_WRITE|PREFER_WRITE)));
+    };
 };
 
 #endif
