@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.h 2484 2007-07-03 15:14:44Z svn $
+ * $Id: ReadWriteLocker.h 2513 2007-07-09 13:05:22Z svn $
  *****************************************************************************/
 
 #ifndef READ_WRITE_LOCKER_H
@@ -43,7 +43,6 @@
 
 #include "AtomicWrapper.h"
 #include "apr_thread_proc.h"
-#include "apr_time.h"
 
 #include "Uncopyable.h"
 #include "Macro.h"
@@ -57,6 +56,32 @@ public:
     static const apr_uint32_t NOT_LOCKED        = 0x0000;
 
 protected:
+    static const apr_uint32_t PREFER_WRITE_SHIFT= 23;
+    static const apr_uint32_t PREFER_WRITE_MASK = 1 << PREFER_WRITE_SHIFT;
+    static const apr_uint32_t WAIT_WRITE_SHIFT  = 22;
+    static const apr_uint32_t WAIT_WRITE_MASK   = 1 << WAIT_WRITE_SHIFT;
+    static const apr_uint32_t AGE_SHIFT         = 16;
+    static const apr_uint32_t AGE_MASK          = 0x3F << AGE_SHIFT;
+    static const apr_uint32_t RESERVED_SHIFT    = 15;
+    static const apr_uint32_t RESERVED_MASK     = 1 << RESERVED_SHIFT;
+    static const apr_uint32_t READ_COUNT_SHIFT  = 0;
+    static const apr_uint32_t READ_COUNT_MASK   = 0x7FFF;
+    static const apr_uint32_t VALID_MASK        = PREFER_WRITE_MASK |
+                                                  WAIT_WRITE_MASK |
+                                                  AGE_MASK |
+                                                  READ_COUNT_MASK;
+
+    static const apr_uint32_t WRITE_LOCKED      = 0xFFFF & READ_COUNT_MASK;
+    static const apr_uint32_t PREFER_WRITE      = 1 << PREFER_WRITE_SHIFT;
+    static const apr_uint32_t PREFER_NONE       = 0 << PREFER_WRITE_SHIFT;
+    static const apr_uint32_t WAIT_WRITE        = 1 << WAIT_WRITE_SHIFT;
+    static const apr_uint32_t WAIT_NONE         = 0 << WAIT_WRITE_SHIFT;
+    static const apr_uint32_t AGE_UINIT         = 1 << AGE_SHIFT;
+    static const apr_uint32_t READ_COUNT_UINIT  = 1 << READ_COUNT_SHIFT;
+
+    static const apr_uint32_t TIMEOUT_CHECK_MASK= 0x1F;
+    static const apr_uint32_t TIMEOUT_SEC       = 180;
+
     /**
      * コンストラクタです．
      *
@@ -64,8 +89,8 @@ protected:
      */
     ReadWriteLocker(apr_atomic_t *lock)
      : lock_(lock),
-       start_age_(0xFFFF),
-       start_time_(apr_time_now()),
+       start_age_(0),
+       start_time_(0),
        status_(0)
     {
 
@@ -79,6 +104,9 @@ protected:
 
     ReadWriteLocker();
 
+    // 注意: ReadWriteLocker 型のポインタ経由で使用されることはないので，
+    // デストラクタは virtual にしない．
+
     /**
      * プロセッサーを明け渡します．
      */
@@ -98,63 +126,43 @@ protected:
      *
      * @param[in] status ロックの状態
      */
-    bool is_timeout(apr_uint32_t status);
-
-    // 注意: ReadWriteLocker 型のポインタ経由で使用されることはないので，
-    // デストラクタは virtual にしない．
-
-    static const apr_size_t PREFER_WRITE_SHIFT  = 23;
-    static const apr_size_t PREFER_WRITE_MASK   = 1 << PREFER_WRITE_SHIFT;
-    static const apr_size_t WAIT_WRITE_SHIFT    = 22;
-    static const apr_size_t WAIT_WRITE_MASK     = 1 << WAIT_WRITE_SHIFT;
-    static const apr_size_t AGE_SHIFT           = 16;
-    static const apr_size_t AGE_MASK            = 0x3F;
-    static const apr_size_t READ_COUNT_SHIFT    = 0;
-    static const apr_size_t READ_COUNT_MASK     = 0xFFFF;
-
-    static const apr_uint32_t WRITE_LOCKED      = 0xFFFF;
-    static const apr_uint32_t PREFER_WRITE      = 1 << PREFER_WRITE_SHIFT;
-    static const apr_uint32_t PREFER_NONE       = 0 << PREFER_WRITE_SHIFT;
-    static const apr_uint32_t WAIT_WRITE        = 1 << WAIT_WRITE_SHIFT;
-    static const apr_uint32_t WAIT_NONE         = 0 << WAIT_WRITE_SHIFT;
-
-    static const apr_size_t TIMEOUT_CHECK_MASK  = 0x1F;
-    static const apr_size_t TIMEOUT_SEC         = 180;
-
-    static apr_uint32_t get_age(apr_uint32_t status)
+    bool should_timeout(apr_uint32_t status);
+    /**
+     * タイムアウトしたかどうか判断します．
+     *
+     * @param[in] curr_status 現在のロックの状態
+     * @param[in] prev_status 以前のロックの状態
+     */
+    bool is_timeout(apr_uint32_t curr_status, apr_uint32_t prev_status)
     {
-        return (status >> AGE_SHIFT) & AGE_MASK;
+        return (((curr_status ^ prev_status) & AGE_MASK) != 0);
     };
     static apr_uint32_t get_read_count(apr_uint32_t status)
     {
-        return (status >> READ_COUNT_SHIFT) & READ_COUNT_MASK;
+        return ((status >> READ_COUNT_SHIFT) & READ_COUNT_MASK);
     };
     static apr_uint32_t get_prefer_write(apr_uint32_t status)
     {
-        return status & PREFER_WRITE_MASK;
+        return (status & PREFER_WRITE_MASK);
     };
     static apr_uint32_t get_wait_write(apr_uint32_t status)
     {
-        return status & WAIT_WRITE_MASK;
+        return (status & WAIT_WRITE_MASK);
     };
-    static apr_uint32_t make_status(apr_uint32_t age, apr_uint32_t read_count,
-                                    apr_uint32_t prefer_write=PREFER_NONE,
-                                    apr_uint32_t wait_write=WAIT_NONE)
-    {
-        return prefer_write | wait_write |
-            ((age & AGE_MASK) << AGE_SHIFT) |
-            ((read_count & READ_COUNT_MASK) << READ_COUNT_SHIFT);
-    };
-    static void log_try_count(const char *label, apr_size_t try_count)
+    static void log_try_count(const char *label, apr_size_t try_count,
+                              apr_uint32_t curr_status,
+                              apr_uint32_t new_status)
     {
 #ifdef DEBUG_LOCK
         std::cerr << "try_count[" << label << "] = " << try_count << std::endl;
+        std::cerr << "state: " << hex << curr_status << " -> ";
+        std::cerr << hex << new_status << std::endl;
         std::cerr.flush();
 #endif
     };
 
     /** 読み出し中のスレッドの数へのポインタ */
-    apr_atomic_t *lock_;
+    apr_atomic_t * const lock_;
     apr_uint32_t start_age_;
     apr_time_t start_time_;
     apr_uint32_t status_;
