@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemIterator.h 2296 2006-12-24 02:58:57Z svn $
+ * $Id: UploadItemIterator.h 2495 2007-07-05 13:53:44Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_ITERATOR_H
@@ -38,6 +38,7 @@
 #include "Uncopyable.h"
 
 
+class UploadItemManager;
 class UploadItemList;
 
 /**
@@ -50,11 +51,11 @@ public:
      * コンストラクタです．
      *
      * @param[in] pool プール
-     * @param[in] item_list アイテムリスト
+     * @param[in] item_manager アイテムマネージャ
      * @param[in] start_index 開始インデックス
      * @param[in] end_index 終了インデックス
      */
-    UploadItemIterator(apr_pool_t *pool, UploadItemList *item_list,
+    UploadItemIterator(apr_pool_t *pool, UploadItemManager *item_manager,
                        apr_size_t start_index, apr_size_t end_index);
     /**
      * 現在位置のアイテムを取得します．
