@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2464 2007-06-30 01:47:25Z svn $
+ * $Id: UploadItemList.h 2466 2007-06-30 02:48:14Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -89,7 +89,7 @@ public:
     };
     bool is_full(apr_uint64_t file_size) const
     {
-        return ((total_file_size_ + file_size) >= max_file_size_) ||
+        return ((total_file_size_ + file_size) > max_file_size_) ||
             (size() >= max_list_size_);
     };
     /**
