@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2485 2007-07-03 15:30:09Z svn $
+ * $Id: WriteLocker.h 2513 2007-07-09 13:05:22Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -35,14 +35,9 @@
 
 #include "ReadWriteLocker.h"
 
-#ifdef DEBUG
-#include <iostream>
-#endif
-
-using namespace std;
 
 /**
-q * @brief 書き込みロックを表すクラス．
+ * @brief 書き込みロックを表すクラス．
  */
 class WriteLocker: public ReadWriteLocker
 {
@@ -63,34 +58,34 @@ public:
         while (1) {
             try_count++;
 
-            curr_status = apr_atomic_read(lock_);
-            if (LIKELY(get_read_count(curr_status) == NOT_LOCKED)) {
-                new_status = make_status(get_age(curr_status), WRITE_LOCKED);
-                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
-                    status_ = new_status;
-                    log_try_count("WriteLock", try_count);
+            curr_status = apr_atomic_read(lock);
+            if (get_read_count(curr_status) == NOT_LOCKED) {
+                new_status = curr_status | WRITE_LOCKED;
+                status_ = new_status; // 先に更新しておく
+                if (apr_atomic_cas(lock, new_status, curr_status) ==
+                    curr_status) {
+                    log_try_count("WriteLock",
+                                  try_count, curr_status, new_status);
                     return;
                 }
             } else {
                 if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
-                    is_timeout(curr_status)) {
+                    should_timeout(curr_status)) {
                     // タイムアウトしたら age を増やす
-                    new_status = make_status(get_age(curr_status) + 1,
-                                             WRITE_LOCKED);
-                    if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
-                        status_ = new_status;
-                        log_try_count("WriteLock(TIME OUT)", try_count);
+                    new_status = ((curr_status | WRITE_LOCKED) + AGE_UINIT) &
+                        VALID_MASK;
+                    status_ = new_status; // 先に更新しておく
+                    if (apr_atomic_cas(lock, new_status, curr_status) ==
+                        curr_status) {
+                        log_try_count("WriteLock(TIME OUT)",
+                                      try_count, curr_status, new_status);
                         return;
                     }
                 }
 
                 if (get_wait_write(curr_status) != WAIT_WRITE) {
-                    (void)apr_atomic_cas(lock_,
-                                         make_status(get_age(curr_status),
-                                                     get_read_count(curr_status),
-                                                     get_prefer_write(curr_status),
-                                                     WAIT_WRITE),
-                                         curr_status);
+                    new_status = curr_status | WAIT_WRITE;
+                    (void)apr_atomic_cas(lock_, new_status, curr_status);
                 }
             }
 
@@ -101,25 +96,25 @@ public:
     {
         apr_size_t try_count;
         apr_uint32_t curr_status;
+        apr_uint32_t new_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
             curr_status = apr_atomic_read(lock_);
-            if (get_age(curr_status) != get_age(status_)) {
+            if (UNLIKELY(is_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
-                log_try_count("WriteUnLock(TIME OUT)", try_count);
+                log_try_count("WriteUnLock(TIME OUT)",
+                              try_count, curr_status, curr_status);
                 return;
             }
 
-            if (apr_atomic_cas(lock_,
-                               make_status(get_age(curr_status),
-                                           NOT_LOCKED,
-                                           PREFER_NONE,
-                                           get_wait_write(curr_status)),
-                               curr_status) == curr_status) {
-                log_try_count("WriteUnLock", try_count);
+            new_status = curr_status & AGE_MASK;
+            if (apr_atomic_cas(lock_, new_status, curr_status) ==
+                curr_status) {
+                log_try_count("WriteUnLock",
+                              try_count, curr_status, new_status);
                 return;
             }
         }
