@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ImageFile.cpp 2326 2006-12-29 17:46:23Z svn $
+ * $Id: ImageFile.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -54,7 +54,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: ImageFile.cpp 2326 2006-12-29 17:46:23Z svn $");
+SOURCE_INFO_ADD("$Id: ImageFile.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -175,7 +175,7 @@ void run_thumbnail(apr_pool_t *pool, const char *thumbnail_dir_path,
         image.create_thumbnail(thumbnail_path,
                                thumbnail_width, thumbnail_height);
 
-        if (!is_exist(pool, thumbnail_path)) {
+        if (!File::is_exist(pool, thumbnail_path)) {
             THROW(MESSAGE_BUG_FOUND);
         }
     }
@@ -200,7 +200,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     image_path_count = argc - 4;
 
     for (apr_size_t i = 0; i < image_path_count; i++) {
-        if (!is_exist(pool, image_path_list[i])) {
+        if (!File::is_exist(pool, image_path_list[i])) {
             THROW(MESSAGE_DATA_DIR_NOT_FOUND);
         }
     }
