@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.cpp 2472 2007-06-30 19:40:38Z svn $
+ * $Id: ReadWriteLocker.cpp 2511 2007-07-07 06:43:31Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,21 +30,21 @@
 #include "ReadWriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2472 2007-06-30 19:40:38Z svn $");
+SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2511 2007-07-07 06:43:31Z svn $");
 
 
 /******************************************************************************
  * protected メソッド
  *****************************************************************************/
-bool ReadWriteLocker::is_timeout(apr_uint32_t status)
+bool ReadWriteLocker::should_timeout(apr_uint32_t status)
 {
     apr_uint32_t curr_age;
     apr_time_t curr_time;
 
-    curr_age = get_age(status);
+    curr_age = status & AGE_MASK;
     curr_time = apr_time_now();
 
-    if (curr_age != start_age_) {
+    if ((start_age_ == 0) || is_timeout(curr_age, start_age_)) {
         start_age_ = curr_age;
         start_time_ = curr_time;
 
