@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemIterator.cpp 2297 2006-12-24 03:13:15Z svn $
+ * $Id: UploadItemIterator.cpp 2509 2007-07-06 22:48:54Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,21 +32,27 @@
 #include "apr.h"
 
 #include "UploadItemIterator.h"
-#include "UploadItemList.h"
+#include "UploadItemManager.h"
+#include "ReadLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2297 2006-12-24 03:13:15Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemIterator.cpp 2509 2007-07-06 22:48:54Z svn $");
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
 UploadItemIterator::UploadItemIterator(apr_pool_t *pool,
-                                       UploadItemList *item_list,
+                                       UploadItemManager *item_manager,
                                        apr_size_t start_index,
                                        apr_size_t end_index)
   : header_list_(NULL),
     curr_index_(0)
 {
+    UploadItemList *item_list;
+    ReadLocker manager_locker(item_manager->lock_);
+
+    item_list = item_manager->item_list_;
+
     validate_index(item_list, &start_index, &end_index);
     size_= end_index - start_index;
 
