@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2464 2007-06-30 01:47:25Z svn $
+ * $Id: UploadItemList.cpp 2508 2007-07-06 22:47:18Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2464 2007-06-30 01:47:25Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2508 2007-07-06 22:47:18Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -230,7 +230,7 @@ void UploadItemList::load_header(UploadItem *uitem,
 void UploadItemList::dump_header(apr_pool_t *pool,
                                UploadItem::header_t *header)
 {
-    cerr << setw(10) << header->id << " ";
+    cerr << setw(10) << static_cast<unsigned int>(header->id) << " ";
     cout << "[" << header->file_name << "] ";
     cout << "("; dump_date(pool, header->mtime); cout << ")" << endl;
 }
