@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2466 2007-06-30 02:48:14Z svn $
+ * $Id: uploader_handler.cpp 2507 2007-07-06 19:08:20Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2466 2007-06-30 02:48:14Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2507 2007-07-06 19:08:20Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -100,6 +100,7 @@ static int redirect(typename Response::Handle *r, typename Response::Writer& o,
     // リダイレクトさせる．
 
     Response::set_content_type(r, PAGE_CONTENT_TYPE);
+    Response::header_end(r);
 
     o.write("<?xml version=\"1.0\" encoding=\"EUC-JP\"?>\n");
     o.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" "
@@ -141,6 +142,7 @@ static int error(typename Response::Handle *r,
                  UploaderConfig *config, const char *message)
 {
     Response::set_content_type(r, PAGE_CONTENT_TYPE);
+    Response::header_end(r);
 
     try {
         UploaderTemplate *tmpl;
@@ -213,6 +215,8 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
         return status;
     }
 #endif
+    Response::header_end(r);
+
     if (Response::is_head_method(r)) {
         return OK;
     }
@@ -230,7 +234,7 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
         end_index = page_no * config->per_page_item_number;
         start_index = end_index - config->per_page_item_number;
 
-        UploadItemIterator item_iter(r->pool, config->get_item_list(),
+        UploadItemIterator item_iter(r->pool, config->get_item_manager(),
                                      start_index, end_index);
 
         tmpl = config->get_template(UploaderConfig::INDEX_VIEW);
@@ -293,11 +297,15 @@ static int thumbnail_view(typename Response::Handle *r, UploaderConfig *config,
         Response::set_last_modified(r,
                                     config->get_item_manager()->get_mtime());
 
+
         int status;
         if ((status = Response::is_meets_condition(r)) != OK) {
+            Response::header_end(r);
             return status;
         }
 #endif
+        Response::header_end(r);
+
         if (Response::is_head_method(r)) {
             return OK;
         }
@@ -334,10 +342,12 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
 
     int status;
     if ((status = Response::is_meets_condition(r)) != OK) {
+        Response::header_end(r);
         return status;
     }
 #endif
     if (Response::is_head_method(r)) {
+        Response::header_end(r);
         return OK;
     }
 
@@ -348,6 +358,7 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
     if (IS_REQUEST_COMMAND(thumbnail_command, THUMBNAIL_VIEW_COMMAND)) {
         return thumbnail_view<Response>(r, config, thumbnail_arg);
     }
+    Response::header_end(r);
 
     get_page_count(config->get_thumbnail_list()->size(),
                    PER_PAGE_THUMBNAIL_NUMBER, &page_count);
@@ -362,7 +373,7 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
         end_index = page_no * PER_PAGE_THUMBNAIL_NUMBER;
         start_index = end_index - PER_PAGE_THUMBNAIL_NUMBER;
 
-        ThumbnailIterator thumbnail_iter(r->pool, config->get_thumbnail_list(),
+        ThumbnailIterator thumbnail_iter(r->pool, config->get_item_manager(),
                                          start_index, end_index);
 
         tmpl = config->get_template(UploaderConfig::THUMBNAIL_VIEW);
@@ -505,6 +516,9 @@ static int progress_data(typename Response::Handle *r, UploaderConfig *config,
     upload_id = static_cast<apr_uint32_t>
         (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
 
+    Response::set_content_type(r, "text/plain");
+    Response::header_end(r);
+
     typename Response::Writer o(r);
 
     // upload_id が 0 の時はエラー．
@@ -596,6 +610,7 @@ static int input_pass(typename Response::Handle *r, UploaderConfig *config,
                       UploadItem *uitem)
 {
     Response::set_content_type(r, PAGE_CONTENT_TYPE);
+    Response::header_end(r);
 
     if (Response::is_head_method(r)) {
         return OK;
@@ -719,6 +734,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
 
         int status;
         if ((status = Response::is_meets_condition(r)) != OK) {
+            Response::header_end(r);
             return status;
         }
 #endif
@@ -753,6 +769,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             (r,
              apr_psprintf(r->pool, "%s; filename=\"%s\"", open_mode,
                           file_name));
+        Response::header_end(r);
 
         Response::set_env(r, "uploader_download", "");
         Response::set_env(r, "uploader_item_id",
@@ -846,6 +863,7 @@ static int rss(typename Response::Handle *r, UploaderConfig *config,
 #ifndef DEBUG
     Response::set_modified_time(r, config->get_item_manager()->get_mtime());
     Response::set_last_modified(r, config->get_item_manager()->get_mtime());
+    Response::header_end(r);
 
     int status;
     if ((status = Response::is_meets_condition(r)) != OK) {
@@ -858,7 +876,7 @@ static int rss(typename Response::Handle *r, UploaderConfig *config,
 
     typename Response::Writer o(r);
     try {
-        UploadItemIterator item_iter(r->pool, config->get_item_list(), 0,
+        UploadItemIterator item_iter(r->pool, config->get_item_manager(), 0,
                                      config->per_page_item_number);
 
         UploadItemRss<typename Response::Writer> item_rss(r->pool, o);
@@ -876,6 +894,7 @@ template<class Response>
 static int info(typename Response::Handle *r, UploaderConfig *config)
 {
     Response::set_content_type(r, "text/plain");
+    Response::header_end(r);
 
     if (Response::is_head_method(r)) {
         return OK;
@@ -899,6 +918,7 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
     apr_size_t page_count;
 
     Response::set_content_type(r, PAGE_CONTENT_TYPE);
+    Response::header_end(r);
 
     if (Response::is_head_method(r)) {
         return OK;
@@ -930,7 +950,7 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
         end_index = page_no * config->per_page_item_number;
         start_index = end_index - config->per_page_item_number;
 
-        UploadItemIterator item_iter(r->pool, config->get_item_list(),
+        UploadItemIterator item_iter(r->pool, config->get_item_manager(),
                                      start_index, end_index);
 
         tmpl = config->get_template(UploaderConfig::ADMIN_VIEW);
